# Spacin
"Spacin, puts space between!"

Spacin is a word-separator that distinguishes each word in a given string.

## Requirements
You need Python 3.6 or later to run spacin. Install Python from [here](https://www.python.org/downloads/).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install spacin:

```bash
pip install spacin
```
or you can download the project from repository and from project's root directory install it:
```bash
pip install .
```

## Usage

```bash
spacin "hellofriend"
```

## Tests
```bash
python3 -m unittest tests/test*
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
